#/bin/sh

##########################################################################
# Shell script function to add an 'intermapper' user and group.
# This function is meant to be called as follows:
#
# imuseradd DEBIAN			Debian 3.0, Debian 3.1, Ubuntu
# imuseradd REDHAT			All Redhat flavors, SuSE, Mandrake
# imuseradd FREEBSD			FreeBSD 4 and 5
# imuseradd SOLARIS			Solaris SPARC and Intel
#
# The script will check whether a user/group 'intermapper' already exists,
# and does nothing if so.  Otherwise it creates them.
#
# On Solaris, the user is called 'intermap' to stay within 8 characters.
##########################################################################

imuseradd()
{
	if [ "$1" = "DEBIAN" ]; then

		if ! getent passwd intermapper > /dev/null; then
			if /usr/sbin/adduser --system --group --disabled-login --home /var/empty --no-create-home intermapper; then
				echo "Created intermapper user and group"
			else
				echo "Unable to create intermapper user and group"
				exit 1
			fi
		else
			echo "The intermapper user already exists (no action required)"
		fi

	elif [ "$1" = "REDHAT" ]; then

		if ! getent passwd intermapper > /dev/null; then
			if /usr/sbin/useradd -M -r -s /sbin/nologin -d /var/empty intermapper; then
				echo "Created intermapper user and group"
			else
				echo "Unable to create intermapper user and group"
				exit 1
			fi
		else
			echo "The intermapper user already exists (no action required)"
		fi

	elif [ "$1" = "SUSE" ]; then

		if ! getent passwd intermapper > /dev/null; then
			if /usr/sbin/groupadd -r intermapper; then
				echo "Created intermapper group"
			else
				echo "Unable to create intermapper group"
				exit 1
			fi

			if /usr/sbin/useradd -g intermapper -M -r -s /sbin/nologin -d /var/empty intermapper; then
				echo "Created intermapper user"
			else
				echo "Unable to create intermapper user"
				exit 1
			fi
		else
			echo "The intermapper user already exists (no action required)"
		fi

	elif [ "$1" = "MANDRAKE" ]; then

		if ! getent passwd intermapper > /dev/null; then
			if /usr/sbin/groupadd -r intermapper; then
				echo "Created intermapper group"
			else
				echo "Unable to create intermapper group"
				exit 1
			fi

			if /usr/sbin/useradd -g intermapper -M -r -s /sbin/nologin -d /var/empty intermapper; then
				echo "Created intermapper user"
			else
				echo "Unable to create intermapper user"
				exit 1
			fi
		else
			echo "The intermapper user already exists (no action required)"
		fi

	elif [ "$1" = "FREEBSD" ]; then

		if ! id intermapper; then

			# Find the highest unused UID number

			high_uid=`cat /etc/passwd | awk -F: '{if ($3 < 1000) print $3;}' | sort -n | tail -1`
			new_uid=`expr $high_uid + 1`

			# If the UID is already in use by a group, find a new one

			new_gid=$new_uid
			check_gid=`cat /etc/group | awk -F: '{if ($3 == "$new_gid") print $3}'`
			if [ "$check_gid" = "$new_gid" ]; then
				high_gid=`cat /etc/group | awk -F: '{if ($3 < 1000 && $3 > 100) print $3; else print 100}' | sort -n | tail -1`
				new_gid=`expr $high_gid + 1`
			fi

			# Create a new user/group with that UID/GID

			if pw groupadd intermapper -g $new_gid; then
				echo "Created intermapper group"
			else
				echo "Unable to create intermapper group"
				exit 1
			fi

			if pw useradd intermapper -u $new_uid -g $new_gid -w no -s /sbin/nologin -d /var/empty; then
				echo "Created intermapper user"
			else
				echo "Unable to create intermapper user"
				exit 1
			fi
		else
			echo "The intermapper user already exists (no action required)"
		fi

	elif [ "$1" = "SOLARIS" ]; then

		if getent passwd intermap > /dev/null; then
			echo "The intermapper user already exists (no action required)"
		else
			# Find the highest unused UID number

			high_uid=`cat /etc/passwd | awk -F: '{if ($3 < 1000 && $3 > 100) print $3; else print 100}' | sort -n | tail -1`
			new_uid=`expr $high_uid + 1`

			# If the UID is already in use by a group, find a new one

			new_gid=$new_uid
			check_gid=`cat /etc/group | awk -F: '{if ($3 == "$new_gid") print $3}'`
			if [ "$check_gid" = "$new_gid" ]; then
				high_gid=`cat /etc/group | awk -F: '{if ($3 < 1000 && $3 > 100) print $3; else print 100}' | sort -n | tail -1`
				new_gid=`expr $high_gid + 1`
			fi

			# Create a new user/group with that UID/GID

			if /usr/sbin/groupadd -g $new_gid intermap; then
				echo "Created intermapper group"
			else
				echo "Unable to create intermapper group"
				exit 1
			fi

			if /usr/sbin/useradd -u $new_uid -g $new_gid -d /var/empty intermap; then
				echo "Created intermapper user"
			else
				echo "Unable to create intermapper user"
				exit 1
			fi
		fi

    else

		echo "You must pass an argument that is one of:"
		echo "DEBIAN, REDHAT, FREEBSD, SOLARIS"

    fi
}

imuseradd "$1"
